Method: AuthorizeNet::CIM::Response#validation_response

Defined in:
lib/authorize_net/cim/response.rb

#validation_responseObject

Returns a validation response as an AuthorizeNet::AIM::Response object if a validation response was returned by the gateway. Returns nil otherwise. Note that this method will return nil if we got back a list of IDs (see validation_responses).



69
70
71
# File 'lib/authorize_net/cim/response.rb', line 69

def validation_response
  AuthorizeNet::AIM::Response.new(@validation_direct_response.dup, @transaction) unless @validation_direct_response.nil?
end